pub struct Obj { /* private fields */ }Expand description
Base class, contains no fields or methods. For Rc-based classes.
Use import and class_unsafe macros
to define a class inherited from Obj:
ⓘ
#[class_unsafe(inherits_Obj)]
struct Class { }Implementations
Sourceimpl Obj
impl Obj
Sourcepub fn new() -> Rc<dyn IsObj>
pub fn new() -> Rc<dyn IsObj>
Creates new Obj class instance, wrapped in Rc smart pointer.
A rarely used function, since it creates Obj itself, not one of its inheritors.
Sourcepub unsafe fn new_raw(vtable: Vtable) -> Self
pub unsafe fn new_raw(vtable: Vtable) -> Self
Creates new Obj.
Intended to be called from inheritors constructors to initialize a base type field.
Safety
Calling this function is safe iff vtable is empty or
generated using the class_unsafe macro on a
direct or indirect Obj inheritor.