pub struct ObjSync { /* private fields */ }Expand description
Base class, contains no fields or methods. For Arc-based classes.
Use import and class_unsafe macros
to define a class inherited from ObjSync:
ⓘ
#[class_unsafe(inherits_ObjSync)]
struct Class { }Implementations
Sourceimpl ObjSync
impl ObjSync
Sourcepub fn new() -> Arc<dyn IsObjSync>
pub fn new() -> Arc<dyn IsObjSync>
Creates new ObjSync class instance, wrapped in Arc smart pointer.
A rarely used function, since it creates ObjSync itself, not one of its inheritors.
Sourcepub unsafe fn new_raw(vtable: Vtable) -> Self
pub unsafe fn new_raw(vtable: Vtable) -> Self
Creates new ObjSync.
Intended to be called from inheritors constructors to initialize a base type field.
Safety
Calling this function is safe iff vtable is empty or
generated using the class_unsafe macro on a
direct or indirect ObjSync inheritor.