pub type Vtable = *const *const ();Expand description
The pointer to the table containing pointers to class virtual functions.
Use class_unsafe macro to generate Vtable.
pub type Vtable = *const *const ();The pointer to the table containing pointers to class virtual functions.
Use class_unsafe macro to generate Vtable.